package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.PosMargin;

/**
 * marginService接口
 * 
 * @author ruoyi
 * @date 2023-08-02
 */
public interface IPosMarginService extends IService<PosMargin>
{
    /**
     * 查询margin
     * 
     * @param id margin主键
     * @return margin
     */
    public PosMargin selectPosMarginById(Long id);

    /**
     * 查询margin列表
     * 
     * @param posMargin margin
     * @return margin集合
     */
    public List<PosMargin> selectPosMarginList(PosMargin posMargin);

    /**
     * 新增margin
     * 
     * @param posMargin margin
     * @return 结果
     */
    public int insertPosMargin(PosMargin posMargin);

    /**
     * 修改margin
     * 
     * @param posMargin margin
     * @return 结果
     */
    public int updatePosMargin(PosMargin posMargin);

    /**
     * 批量删除margin
     * 
     * @param ids 需要删除的margin主键集合
     * @return 结果
     */
    public int deletePosMarginByIds(Long[] ids);

    /**
     * 删除margin信息
     * 
     * @param id margin主键
     * @return 结果
     */
    public int deletePosMarginById(Long id);
}
